@@ -15,6 +15,7 @@ import re
 import sys
 import inspect
 import traceback
+import warnings
 from types import FunctionType, BuiltinFunctionType, MethodType
 
 from six import PY2, iterkeys, iteritems, itervalues, text_type, class_types, \
@@ -31,7 +32,8 @@ from sphinx.application import ExtensionError
 from sphinx.util.nodes import nested_parse_with_titles
 from sphinx.util.compat import Directive
 from sphinx.util.inspect import getargspec, isdescriptor, safe_getmembers, \
-    safe_getattr, object_description, is_builtin_class_method, isenumattribute
+    safe_getattr, object_description, is_builtin_class_method, \
+    isenumclass, isenumattribute
 from sphinx.util.docstrings import prepare_docstring
 
 try:
@@ -544,7 +546,9 @@ class Documenter(object):
             for modname in self.env.config.autodoc_mock_imports:
                 dbg('[autodoc] adding a mock module %s!', modname)
                 mock_import(modname)
-            __import__(self.modname)
+            with warnings.catch_warnings():
+                warnings.filterwarnings("ignore", category=ImportWarning)
+                __import__(self.modname)
             parent = None
             obj = self.module = sys.modules[self.modname]
             dbg('[autodoc] => %r', obj)
@@ -771,6 +775,14 @@ class Documenter(object):
             else:
                 members = [(mname, self.get_attr(self.object, mname, None))
                            for mname in list(iterkeys(obj_dict))]
+
+            # Py34 doesn't have enum members in __dict__.
+            if isenumclass(self.object):
+                members.extend(
+                    item for item in self.object.__members__.items()
+                    if item not in members
+                )
+
         membernames = set(m[0] for m in members)
         # add instance attributes from the analyzer
         for aname in analyzed_member_names:
