@@ -43,9 +43,6 @@ from sphinx.util import texescape
 
 TERM_ENCODING = getattr(sys.stdin, 'encoding', None)
 
-# function to get input from terminal -- overridden by the test suite
-term_input = input
-
 DEFAULT_VALUE = {
     'path': '.',
     'sep': False,
@@ -73,6 +70,12 @@ def mkdir_p(dir):
     os.makedirs(dir)
 
 
+# function to get input from terminal -- overridden by the test suite
+def term_input(prompt):
+    print(prompt, end='')
+    return input('')
+
+
 class ValidationError(Exception):
     """Raised for validation errors."""
 
@@ -435,7 +438,10 @@ def generate(d, overwrite=True, silent=False, templatedir=None):
         else:
             print('File %s already exists, skipping.' % fpath)
 
-    with open(os.path.join(package_dir, 'templates', 'quickstart', 'conf.py_t')) as f:
+    conf_path = os.path.join(templatedir, 'conf.py_t') if templatedir else None
+    if not conf_path or not path.isfile(conf_path):
+        conf_path = os.path.join(package_dir, 'templates', 'quickstart', 'conf.py_t')
+    with open(conf_path) as f:
         conf_text = convert_python_source(f.read())
 
     write_file(path.join(srcdir, 'conf.py'), template.render_string(conf_text, d))
